@@ -1,5 +1,5 @@
 dataReading <-
-function(IPfile, controlFile, chromosomalFeatures = ""){
+function(IPfile, controlFile, yeastSpecies = NULL){
 
 #######
 # written by G. LELANDAIS <gaelle.lelandais@univ-paris-diderot.fr>    
@@ -7,27 +7,18 @@ function(IPfile, controlFile, chromosomalFeatures = ""){
 
     print("**********************************************")
     print("Reading IP and control datasets... ")
-
+ 
     IPdata = read.table(IPfile)
     controlData = read.table(controlFile)
 
     print("... done")
 
-    if(chromosomalFeatures != ""){
-    
-        print("Reading chromosomal features for peak location... ")
-
-        ORFinfo = as.matrix(read.table(chromosomalFeatures, sep = "\t"))
-
-        print("... done")
-    }else{
-        ORFinfo = NULL
-    }
+    cdsPositions = yeastSpecies
     
     print("**********************************************")
     print("")
 
-    return(list(IPdata = IPdata, controlData = controlData, chromosomalFeatures = ORFinfo))
+    return(list(IPdata = IPdata, controlData = controlData, cdsPositions = cdsPositions))
 
 # end of function dataReading()
 }
